You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by vk...@apache.org on 2014/12/11 14:54:26 UTC

[17/56] [abbrv] [partial] incubator-ignite git commit: Rename GridException to IgniteCheckedException, GridRuntimeException to IgniteException.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioAsyncNotifyFilter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioAsyncNotifyFilter.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioAsyncNotifyFilter.java
index 53beb21..49dfcd5 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioAsyncNotifyFilter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioAsyncNotifyFilter.java
@@ -51,13 +51,13 @@ public class GridNioAsyncNotifyFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionOpened(final GridNioSession ses) throws GridException {
+    @Override public void onSessionOpened(final GridNioSession ses) throws IgniteCheckedException {
         workerPool.execute(new GridWorker(gridName, "session-opened-notify", log) {
             @Override protected void body() {
                 try {
                     proceedSessionOpened(ses);
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     handleException(ses, e);
                 }
             }
@@ -65,13 +65,13 @@ public class GridNioAsyncNotifyFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionClosed(final GridNioSession ses) throws GridException {
+    @Override public void onSessionClosed(final GridNioSession ses) throws IgniteCheckedException {
         workerPool.execute(new GridWorker(gridName, "session-closed-notify", log) {
             @Override protected void body() {
                 try {
                     proceedSessionClosed(ses);
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     handleException(ses, e);
                 }
             }
@@ -80,13 +80,13 @@ public class GridNioAsyncNotifyFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void onMessageReceived(final GridNioSession ses, final Object msg) throws GridException {
+    @Override public void onMessageReceived(final GridNioSession ses, final Object msg) throws IgniteCheckedException {
         workerPool.execute(new GridWorker(gridName, "message-received-notify", log) {
             @Override protected void body() {
                 try {
                     proceedMessageReceived(ses, msg);
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     handleException(ses, e);
                 }
             }
@@ -94,27 +94,27 @@ public class GridNioAsyncNotifyFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void onExceptionCaught(GridNioSession ses, GridException ex) throws GridException {
+    @Override public void onExceptionCaught(GridNioSession ses, IgniteCheckedException ex) throws IgniteCheckedException {
         proceedExceptionCaught(ses, ex);
     }
 
     /** {@inheritDoc} */
-    @Override public GridNioFuture<?> onSessionWrite(GridNioSession ses, Object msg) throws GridException {
+    @Override public GridNioFuture<?> onSessionWrite(GridNioSession ses, Object msg) throws IgniteCheckedException {
         return proceedSessionWrite(ses, msg);
     }
 
     /** {@inheritDoc} */
-    @Override public GridNioFuture<Boolean> onSessionClose(GridNioSession ses) throws GridException {
+    @Override public GridNioFuture<Boolean> onSessionClose(GridNioSession ses) throws IgniteCheckedException {
         return proceedSessionClose(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionIdleTimeout(GridNioSession ses) throws GridException {
+    @Override public void onSessionIdleTimeout(GridNioSession ses) throws IgniteCheckedException {
         proceedSessionIdleTimeout(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionWriteTimeout(GridNioSession ses) throws GridException {
+    @Override public void onSessionWriteTimeout(GridNioSession ses) throws IgniteCheckedException {
         proceedSessionWriteTimeout(ses);
     }
 
@@ -122,11 +122,11 @@ public class GridNioAsyncNotifyFilter extends GridNioFilterAdapter {
      * @param ses Session.
      * @param ex Exception.
      */
-    private void handleException(GridNioSession ses, GridException ex) {
+    private void handleException(GridNioSession ses, IgniteCheckedException ex) {
         try {
             proceedExceptionCaught(ses, ex);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             U.warn(log, "Failed to forward exception to the underlying filter (will ignore) [ses=" + ses + ", " +
                 "originalEx=" + ex + ", ex=" + e + ']');
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioCodecFilter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioCodecFilter.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioCodecFilter.java
index 4a730a5..1a59155 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioCodecFilter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioCodecFilter.java
@@ -53,22 +53,22 @@ public class GridNioCodecFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionOpened(GridNioSession ses) throws GridException {
+    @Override public void onSessionOpened(GridNioSession ses) throws IgniteCheckedException {
         proceedSessionOpened(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionClosed(GridNioSession ses) throws GridException {
+    @Override public void onSessionClosed(GridNioSession ses) throws IgniteCheckedException {
         proceedSessionClosed(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void onExceptionCaught(GridNioSession ses, GridException ex) throws GridException {
+    @Override public void onExceptionCaught(GridNioSession ses, IgniteCheckedException ex) throws IgniteCheckedException {
         proceedExceptionCaught(ses, ex);
     }
 
     /** {@inheritDoc} */
-    @Override public GridNioFuture<?> onSessionWrite(GridNioSession ses, Object msg) throws GridException {
+    @Override public GridNioFuture<?> onSessionWrite(GridNioSession ses, Object msg) throws IgniteCheckedException {
         // No encoding needed in direct mode.
         if (directMode)
             return proceedSessionWrite(ses, msg);
@@ -84,7 +84,7 @@ public class GridNioCodecFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void onMessageReceived(GridNioSession ses, Object msg) throws GridException {
+    @Override public void onMessageReceived(GridNioSession ses, Object msg) throws IgniteCheckedException {
         if (!(msg instanceof ByteBuffer))
             throw new GridNioException("Failed to decode incoming message (incoming message is not a byte buffer, " +
                 "is filter properly placed?): " + msg.getClass());
@@ -116,17 +116,17 @@ public class GridNioCodecFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public GridNioFuture<Boolean> onSessionClose(GridNioSession ses) throws GridException {
+    @Override public GridNioFuture<Boolean> onSessionClose(GridNioSession ses) throws IgniteCheckedException {
         return proceedSessionClose(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionIdleTimeout(GridNioSession ses) throws GridException {
+    @Override public void onSessionIdleTimeout(GridNioSession ses) throws IgniteCheckedException {
         proceedSessionIdleTimeout(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionWriteTimeout(GridNioSession ses) throws GridException {
+    @Override public void onSessionWriteTimeout(GridNioSession ses) throws IgniteCheckedException {
         proceedSessionWriteTimeout(ses);
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioEmbeddedFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioEmbeddedFuture.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioEmbeddedFuture.java
index 94511e7..4f55eb8 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioEmbeddedFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioEmbeddedFuture.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.util.nio;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
@@ -50,7 +50,7 @@ public class GridNioEmbeddedFuture<R> extends GridNioFutureImpl<R> {
                 try {
                     onDone(t.get());
                 }
-                catch (IOException | GridException e) {
+                catch (IOException | IgniteCheckedException e) {
                     onDone(e);
                 }
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioException.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioException.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioException.java
index 92cf652..a4d9882 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioException.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioException.java
@@ -9,13 +9,13 @@
 
 package org.gridgain.grid.util.nio;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 /**
  * Nio specific exception.
  */
-public class GridNioException extends GridException {
+public class GridNioException extends IgniteCheckedException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilterAdapter.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilterAdapter.java
index a4dfcaa..b340179 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilterAdapter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilterAdapter.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.util.nio;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 /**
  * Class that defines the piece for application-to-network and vice-versa data conversions
@@ -72,82 +72,82 @@ public abstract class GridNioFilterAdapter implements GridNioFilter {
     }
 
     /** {@inheritDoc} */
-    @Override public void proceedSessionOpened(GridNioSession ses) throws GridException {
+    @Override public void proceedSessionOpened(GridNioSession ses) throws IgniteCheckedException {
         checkPrevious();
 
         prevFilter.onSessionOpened(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void proceedSessionClosed(GridNioSession ses) throws GridException {
+    @Override public void proceedSessionClosed(GridNioSession ses) throws IgniteCheckedException {
         checkPrevious();
 
         prevFilter.onSessionClosed(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void proceedExceptionCaught(GridNioSession ses, GridException e) throws GridException {
+    @Override public void proceedExceptionCaught(GridNioSession ses, IgniteCheckedException e) throws IgniteCheckedException {
         checkPrevious();
 
         prevFilter.onExceptionCaught(ses, e);
     }
 
     /** {@inheritDoc} */
-    @Override public void proceedMessageReceived(GridNioSession ses, Object msg) throws GridException {
+    @Override public void proceedMessageReceived(GridNioSession ses, Object msg) throws IgniteCheckedException {
         checkPrevious();
 
         prevFilter.onMessageReceived(ses, msg);
     }
 
     /** {@inheritDoc} */
-    @Override public GridNioFuture<?> proceedSessionWrite(GridNioSession ses, Object msg) throws GridException {
+    @Override public GridNioFuture<?> proceedSessionWrite(GridNioSession ses, Object msg) throws IgniteCheckedException {
         checkNext();
 
         return nextFilter.onSessionWrite(ses, msg);
     }
 
     /** {@inheritDoc} */
-    @Override public GridNioFuture<Boolean> proceedSessionClose(GridNioSession ses) throws GridException {
+    @Override public GridNioFuture<Boolean> proceedSessionClose(GridNioSession ses) throws IgniteCheckedException {
         checkNext();
 
         return nextFilter.onSessionClose(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void proceedSessionIdleTimeout(GridNioSession ses) throws GridException {
+    @Override public void proceedSessionIdleTimeout(GridNioSession ses) throws IgniteCheckedException {
         checkPrevious();
 
         prevFilter.onSessionIdleTimeout(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void proceedSessionWriteTimeout(GridNioSession ses) throws GridException {
+    @Override public void proceedSessionWriteTimeout(GridNioSession ses) throws IgniteCheckedException {
         checkPrevious();
 
         prevFilter.onSessionWriteTimeout(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public GridNioFuture<?> proceedPauseReads(GridNioSession ses) throws GridException {
+    @Override public GridNioFuture<?> proceedPauseReads(GridNioSession ses) throws IgniteCheckedException {
         checkNext();
 
         return nextFilter.onPauseReads(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public GridNioFuture<?> proceedResumeReads(GridNioSession ses) throws GridException {
+    @Override public GridNioFuture<?> proceedResumeReads(GridNioSession ses) throws IgniteCheckedException {
         checkNext();
 
         return nextFilter.onResumeReads(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public GridNioFuture<?> onPauseReads(GridNioSession ses) throws GridException {
+    @Override public GridNioFuture<?> onPauseReads(GridNioSession ses) throws IgniteCheckedException {
         return proceedPauseReads(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public GridNioFuture<?> onResumeReads(GridNioSession ses) throws GridException {
+    @Override public GridNioFuture<?> onResumeReads(GridNioSession ses) throws IgniteCheckedException {
         return proceedResumeReads(ses);
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilterChain.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFinishedFuture.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFinishedFuture.java
index 980b548..3fa76fc 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFinishedFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFinishedFuture.java
@@ -8,8 +8,8 @@
  */
 package org.gridgain.grid.util.nio;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
@@ -48,7 +48,7 @@ public class GridNioFinishedFuture<R> implements GridNioFuture<R> {
     }
 
     /** {@inheritDoc} */
-    @Override public R get() throws IOException, GridException {
+    @Override public R get() throws IOException, IgniteCheckedException {
         if (err != null) {
             if (err instanceof IOException)
                 throw (IOException)err;
@@ -60,17 +60,17 @@ public class GridNioFinishedFuture<R> implements GridNioFuture<R> {
     }
 
     /** {@inheritDoc} */
-    @Override public R get(long timeout) throws IOException, GridException {
+    @Override public R get(long timeout) throws IOException, IgniteCheckedException {
         return get();
     }
 
     /** {@inheritDoc} */
-    @Override public R get(long timeout, TimeUnit unit) throws IOException, GridException {
+    @Override public R get(long timeout, TimeUnit unit) throws IOException, IgniteCheckedException {
         return get();
     }
 
     /** {@inheritDoc} */
-    @Override public boolean cancel() throws GridException {
+    @Override public boolean cancel() throws IgniteCheckedException {
         return false;
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioSessionImpl.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioSessionImpl.java
index d81f98f..30fd345 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioSessionImpl.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioSessionImpl.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.util.nio;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
@@ -93,7 +93,7 @@ public class GridNioSessionImpl implements GridNioSession {
 
             return chain().onSessionWrite(this, msg);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             close();
 
             return new GridNioFinishedFuture<Object>(e);
@@ -105,7 +105,7 @@ public class GridNioSessionImpl implements GridNioSession {
         try {
             return chain().onResumeReads(this);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             close();
 
             return new GridNioFinishedFuture<Object>(e);
@@ -117,7 +117,7 @@ public class GridNioSessionImpl implements GridNioSession {
         try {
             return chain().onPauseReads(this);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             close();
 
             return new GridNioFinishedFuture<Object>(e);
@@ -130,7 +130,7 @@ public class GridNioSessionImpl implements GridNioSession {
         try {
             return filterChain.onSessionClose(this);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             return new GridNioFinishedFuture<>(e);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridShmemCommunicationClient.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridTcpNioCommunicationClient.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridTcpNioCommunicationClient.java
index 6d2a8f7..49053d3 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridTcpNioCommunicationClient.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridTcpNioCommunicationClient.java
@@ -9,11 +9,11 @@
 
 package org.gridgain.grid.util.nio;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.direct.*;
-import org.jetbrains.annotations.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.lang.*;
+import org.gridgain.grid.util.typedef.internal.*;
+import org.jetbrains.annotations.*;
 
 import java.io.*;
 import java.nio.*;
@@ -54,7 +54,7 @@ public class GridTcpNioCommunicationClient extends GridAbstractCommunicationClie
     }
 
     /** {@inheritDoc} */
-    @Override public void doHandshake(IgniteInClosure2X<InputStream, OutputStream> handshakeC) throws GridException {
+    @Override public void doHandshake(IgniteInClosure2X<InputStream, OutputStream> handshakeC) throws IgniteCheckedException {
         throw new UnsupportedOperationException();
     }
 
@@ -76,14 +76,14 @@ public class GridTcpNioCommunicationClient extends GridAbstractCommunicationClie
     }
 
     /** {@inheritDoc} */
-    @Override public void sendMessage(byte[] data, int len) throws GridException {
+    @Override public void sendMessage(byte[] data, int len) throws IgniteCheckedException {
         throw new UnsupportedOperationException();
     }
 
     /** {@inheritDoc} */
-    @Override public void sendMessage(ByteBuffer data) throws GridException {
+    @Override public void sendMessage(ByteBuffer data) throws IgniteCheckedException {
         if (closed())
-            throw new GridException("Client was closed: " + this);
+            throw new IgniteCheckedException("Client was closed: " + this);
 
         GridNioFuture<?> fut = ses.send(data);
 
@@ -92,19 +92,19 @@ public class GridTcpNioCommunicationClient extends GridAbstractCommunicationClie
                 fut.get();
             }
             catch (IOException e) {
-                throw new GridException("Failed to send message [client=" + this + ']', e);
+                throw new IgniteCheckedException("Failed to send message [client=" + this + ']', e);
             }
         }
     }
 
     /** {@inheritDoc} */
     @Override public void sendMessage(@Nullable UUID nodeId, GridTcpCommunicationMessageAdapter msg)
-        throws GridException {
+        throws IgniteCheckedException {
         // Node ID is never provided in asynchronous send mode.
         assert nodeId == null;
 
         if (closed())
-            throw new GridException("Client was closed: " + this);
+            throw new IgniteCheckedException("Client was closed: " + this);
 
         GridNioFuture<?> fut = ses.send(msg);
 
@@ -113,7 +113,7 @@ public class GridTcpNioCommunicationClient extends GridAbstractCommunicationClie
                 fut.get();
             }
             catch (IOException e) {
-                throw new GridException("Failed to send message [client=" + this + ']', e);
+                throw new IgniteCheckedException("Failed to send message [client=" + this + ']', e);
             }
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/ssl/GridNioSslFilter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/ssl/GridNioSslFilter.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/ssl/GridNioSslFilter.java
index 282c0e1..c7a3371 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/ssl/GridNioSslFilter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/ssl/GridNioSslFilter.java
@@ -123,7 +123,7 @@ public class GridNioSslFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionOpened(GridNioSession ses) throws GridException {
+    @Override public void onSessionOpened(GridNioSession ses) throws IgniteCheckedException {
         if (log.isDebugEnabled())
             log.debug("Remote client connected, creating SSL handler and performing initial handshake: " + ses);
 
@@ -158,14 +158,14 @@ public class GridNioSslFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionClosed(GridNioSession ses) throws GridException {
+    @Override public void onSessionClosed(GridNioSession ses) throws IgniteCheckedException {
         GridNioSslHandler hnd = sslHandler(ses);
 
         try {
             GridNioFutureImpl<?> fut = ses.removeMeta(HANDSHAKE_FUT_META_KEY);
 
             if (fut != null)
-                fut.onDone(new GridException("SSL handshake failed (connection closed)."));
+                fut.onDone(new IgniteCheckedException("SSL handshake failed (connection closed)."));
 
             hnd.shutdown();
         }
@@ -175,7 +175,7 @@ public class GridNioSslFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void onExceptionCaught(GridNioSession ses, GridException ex) throws GridException {
+    @Override public void onExceptionCaught(GridNioSession ses, IgniteCheckedException ex) throws IgniteCheckedException {
         proceedExceptionCaught(ses, ex);
     }
 
@@ -221,7 +221,7 @@ public class GridNioSslFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public GridNioFuture<?> onSessionWrite(GridNioSession ses, Object msg) throws GridException {
+    @Override public GridNioFuture<?> onSessionWrite(GridNioSession ses, Object msg) throws IgniteCheckedException {
         if (directMode)
             return proceedSessionWrite(ses, msg);
 
@@ -260,7 +260,7 @@ public class GridNioSslFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void onMessageReceived(GridNioSession ses, Object msg) throws GridException {
+    @Override public void onMessageReceived(GridNioSession ses, Object msg) throws IgniteCheckedException {
         ByteBuffer input = checkMessage(ses, msg);
 
         GridNioSslHandler hnd = sslHandler(ses);
@@ -299,7 +299,7 @@ public class GridNioSslFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public GridNioFuture<Boolean> onSessionClose(GridNioSession ses) throws GridException {
+    @Override public GridNioFuture<Boolean> onSessionClose(GridNioSession ses) throws IgniteCheckedException {
         GridNioSslHandler hnd = sslHandler(ses);
 
         hnd.lock();
@@ -320,7 +320,7 @@ public class GridNioSslFilter extends GridNioFilterAdapter {
      * @throws GridNioException If failed to forward requests to filter chain.
      * @return Close future.
      */
-    private GridNioFuture<Boolean> shutdownSession(GridNioSession ses, GridNioSslHandler hnd) throws GridException {
+    private GridNioFuture<Boolean> shutdownSession(GridNioSession ses, GridNioSslHandler hnd) throws IgniteCheckedException {
         try {
             hnd.closeOutbound();
 
@@ -334,12 +334,12 @@ public class GridNioSslFilter extends GridNioFilterAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionIdleTimeout(GridNioSession ses) throws GridException {
+    @Override public void onSessionIdleTimeout(GridNioSession ses) throws IgniteCheckedException {
         proceedSessionIdleTimeout(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionWriteTimeout(GridNioSession ses) throws GridException {
+    @Override public void onSessionWriteTimeout(GridNioSession ses) throws IgniteCheckedException {
         proceedSessionWriteTimeout(ses);
     }
 
@@ -353,7 +353,7 @@ public class GridNioSslFilter extends GridNioFilterAdapter {
         GridNioSslHandler hnd = ses.meta(SSL_HANDLER.ordinal());
 
         if (hnd == null)
-            throw new GridRuntimeException("Failed to process incoming message (received message before SSL handler " +
+            throw new IgniteException("Failed to process incoming message (received message before SSL handler " +
                 "was created): " + ses);
 
         return hnd;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/ssl/GridNioSslHandler.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/ssl/GridNioSslHandler.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/ssl/GridNioSslHandler.java
index dbfd293..94657ed 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/ssl/GridNioSslHandler.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/ssl/GridNioSslHandler.java
@@ -140,7 +140,7 @@ class GridNioSslHandler extends ReentrantLock {
      * @throws GridNioException If filter processing has thrown an exception.
      * @throws SSLException If failed to process SSL data.
      */
-    void handshake() throws GridException, SSLException {
+    void handshake() throws IgniteCheckedException, SSLException {
         if (log.isDebugEnabled())
             log.debug("Entered handshake(): [handshakeStatus=" + handshakeStatus + ", ses=" + ses + ']');
 
@@ -244,7 +244,7 @@ class GridNioSslHandler extends ReentrantLock {
      * @throws GridNioException If exception occurred while forwarding events to underlying filter.
      * @throws SSLException If failed to process SSL data.
      */
-    void messageReceived(ByteBuffer buf) throws GridException, SSLException {
+    void messageReceived(ByteBuffer buf) throws IgniteCheckedException, SSLException {
         if (buf.limit() > inNetBuf.remaining()) {
             inNetBuf = expandBuffer(inNetBuf, inNetBuf.capacity() + buf.limit() * 2);
 
@@ -373,7 +373,7 @@ class GridNioSslHandler extends ReentrantLock {
      * Flushes all deferred write events.
      * @throws GridNioException If failed to forward writes to the filter.
      */
-    void flushDeferredWrites() throws GridException {
+    void flushDeferredWrites() throws IgniteCheckedException {
         assert isHeldByCurrentThread();
         assert handshakeFinished;
 
@@ -420,7 +420,7 @@ class GridNioSslHandler extends ReentrantLock {
      * @return Write future.
      * @throws GridNioException If send failed.
      */
-    GridNioFuture<?> writeNetBuffer() throws GridException {
+    GridNioFuture<?> writeNetBuffer() throws IgniteCheckedException {
         assert isHeldByCurrentThread();
 
         ByteBuffer cp = copy(outNetBuf);
@@ -434,7 +434,7 @@ class GridNioSslHandler extends ReentrantLock {
      * @throws SSLException If failed to process SSL data.
      * @throws GridNioException If failed to pass events to the next filter.
      */
-    private void unwrapData() throws GridException, SSLException {
+    private void unwrapData() throws IgniteCheckedException, SSLException {
         if (log.isDebugEnabled())
             log.debug("Unwrapping received data: " + ses);
 
@@ -458,7 +458,7 @@ class GridNioSslHandler extends ReentrantLock {
      * @throws SSLException If SSL exception occurred while unwrapping.
      * @throws GridNioException If failed to pass event to the next filter.
      */
-    private Status unwrapHandshake() throws SSLException, GridException {
+    private Status unwrapHandshake() throws SSLException, IgniteCheckedException {
         // Flip input buffer so we can read the collected data.
         inNetBuf.flip();
 
@@ -493,7 +493,7 @@ class GridNioSslHandler extends ReentrantLock {
      * @throws GridNioException If exception occurred during handshake.
      * @throws SSLException If failed to process SSL data
      */
-    private void renegotiateIfNeeded(SSLEngineResult res) throws GridException, SSLException {
+    private void renegotiateIfNeeded(SSLEngineResult res) throws IgniteCheckedException, SSLException {
         if (res.getStatus() != CLOSED && res.getStatus() != BUFFER_UNDERFLOW
             && res.getHandshakeStatus() != NOT_HANDSHAKING) {
             // Renegotiation required.
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilter.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilter.java
index 33a41d6..00d1ab7 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilter.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.util.nio;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 /**
  * This interface defines the general element in transformation chain between the nio server and
@@ -62,35 +62,35 @@ public interface GridNioFilter {
      * Forwards session opened event to the next logical filter in filter chain.
      *
      * @param ses Opened session.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public void proceedSessionOpened(GridNioSession ses) throws GridException;
+    public void proceedSessionOpened(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Forwards session closed event to the next logical filter in filter chain.
      *
      * @param ses Closed session.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public void proceedSessionClosed(GridNioSession ses) throws GridException;
+    public void proceedSessionClosed(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Forwards GridNioException event to the next logical filter in filter chain.
      *
      * @param ses Session instance.
      * @param e GridNioException instance.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public void proceedExceptionCaught(GridNioSession ses, GridException e) throws GridException;
+    public void proceedExceptionCaught(GridNioSession ses, IgniteCheckedException e) throws IgniteCheckedException;
 
     /**
      * Forwards received message to the next logical filter in filter chain.
      *
      * @param ses Session instance.
      * @param msg Received message.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public void proceedMessageReceived(GridNioSession ses, Object msg) throws GridException;
+    public void proceedMessageReceived(GridNioSession ses, Object msg) throws IgniteCheckedException;
 
     /**
      * Forwards write request to the next logical filter in filter chain.
@@ -98,43 +98,43 @@ public interface GridNioFilter {
      * @param ses Session instance.
      * @param msg Message to send.
      * @return Write future.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public GridNioFuture<?> proceedSessionWrite(GridNioSession ses, Object msg) throws GridException;
+    public GridNioFuture<?> proceedSessionWrite(GridNioSession ses, Object msg) throws IgniteCheckedException;
 
     /**
      * Forwards session close request to the next logical filter in filter chain.
      *
      * @param ses Session instance.
      * @return Close future.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public GridNioFuture<Boolean> proceedSessionClose(GridNioSession ses) throws GridException;
+    public GridNioFuture<Boolean> proceedSessionClose(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Invoked when a new session was created.
      *
      * @param ses Opened session.
      * @throws GridException If GridNioException occurred while handling event.
      */
-    public void onSessionOpened(GridNioSession ses) throws GridException;
+    public void onSessionOpened(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Invoked after session get closed.
      *
      * @param ses Closed session.
      * @throws GridException If GridNioException occurred while handling event.
      */
-    public void onSessionClosed(GridNioSession ses) throws GridException;
+    public void onSessionClosed(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Invoked when exception is caught in filter processing.
      *
      * @param ses Session that caused GridException.
      * @param ex GridNioException instance.
      * @throws GridException If GridException occurred while handling event.
      */
-    public void onExceptionCaught(GridNioSession ses, GridException ex) throws GridException;
+    public void onExceptionCaught(GridNioSession ses, IgniteCheckedException ex) throws IgniteCheckedException;
 
     /**
      * Invoked when a write request is performed on a session.
@@ -144,93 +144,93 @@ public interface GridNioFilter {
      * @return Write future.
      * @throws GridNioException If GridNioException occurred while handling event.
      */
-    public GridNioFuture<?> onSessionWrite(GridNioSession ses, Object msg) throws GridException;
+    public GridNioFuture<?> onSessionWrite(GridNioSession ses, Object msg) throws IgniteCheckedException;
 
     /**
      * Invoked when a new messages received.
      *
      * @param ses Session on which message was received.
      * @param msg Received message.
      * @throws GridException If GridException occurred while handling event.
      */
-    public void onMessageReceived(GridNioSession ses, Object msg) throws GridException;
+    public void onMessageReceived(GridNioSession ses, Object msg) throws IgniteCheckedException;
 
     /**
      * Invoked when a session close request is performed on session.
      *
      * @param ses Session to close.
      * @return Close future.
      * @throws GridException If GridException occurred while handling event.
      */
-    public GridNioFuture<Boolean> onSessionClose(GridNioSession ses) throws GridException;
+    public GridNioFuture<Boolean> onSessionClose(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Called when session is idle for longer time that is
      * allowed by NIO server.
      *
      * @param ses Session that is idle.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public void onSessionIdleTimeout(GridNioSession ses) throws GridException;
+    public void onSessionIdleTimeout(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Forwards session idle notification to the next logical filter in filter chain.
      *
      * @param ses Session instance.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public void proceedSessionIdleTimeout(GridNioSession ses) throws GridException;
+    public void proceedSessionIdleTimeout(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Called when session has not empty write buffer that has not been fully
      * flushed during max timeout allowed by NIO server.
      *
      * @param ses Session that has timed out writes.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public void onSessionWriteTimeout(GridNioSession ses) throws GridException;
+    public void onSessionWriteTimeout(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Forwards session write timeout notification to the next logical filter in filter chain.
      *
      * @param ses Session instance.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public void proceedSessionWriteTimeout(GridNioSession ses) throws GridException;
+    public void proceedSessionWriteTimeout(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Pauses reads for session.
      *
      * @param ses Session.
      * @return Future for operation.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public GridNioFuture<?> proceedPauseReads(GridNioSession ses) throws GridException;
+    public GridNioFuture<?> proceedPauseReads(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Pauses reads for session.
      *
      * @param ses Session.
      * @return Future for operation.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public GridNioFuture<?> onPauseReads(GridNioSession ses) throws GridException;
+    public GridNioFuture<?> onPauseReads(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Resumes reads for session.
      *
      * @param ses Session.
      * @return Future for operation.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public GridNioFuture<?> proceedResumeReads(GridNioSession ses) throws GridException;
+    public GridNioFuture<?> proceedResumeReads(GridNioSession ses) throws IgniteCheckedException;
 
     /**
      * Resumes reads for session.
      *
      * @param ses Session.
      * @return Future for operation.
      * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
-    public GridNioFuture<?> onResumeReads(GridNioSession ses) throws GridException;
+    public GridNioFuture<?> onResumeReads(GridNioSession ses) throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilterAdapter.java
----------------------------------------------------------------------
@@ -62,35 +62,35 @@ public interface GridNioFilter {
      *
      * @param ses Opened session.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -62,35 +62,35 @@ public interface GridNioFilter {
      *
      * @param ses Closed session.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -62,35 +62,35 @@ public interface GridNioFilter {
      * @param ses Session instance.
      * @param e GridNioException instance.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -62,35 +62,35 @@ public interface GridNioFilter {
      * @param ses Session instance.
      * @param msg Received message.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -98,43 +98,43 @@ public interface GridNioFilter {
      * @param msg Message to send.
      * @return Write future.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -98,43 +98,43 @@ public interface GridNioFilter {
      * @param ses Session instance.
      * @return Close future.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -98,43 +98,43 @@ public interface GridNioFilter {
      *
      * @param ses Opened session.
-     * @throws GridException If GridNioException occurred while handling event.
+     * @throws IgniteCheckedException If GridNioException occurred while handling event.
      */
@@ -98,43 +98,43 @@ public interface GridNioFilter {
      *
      * @param ses Closed session.
-     * @throws GridException If GridNioException occurred while handling event.
+     * @throws IgniteCheckedException If GridNioException occurred while handling event.
      */
@@ -98,43 +98,43 @@ public interface GridNioFilter {
      * Invoked when exception is caught in filter processing.
      *
-     * @param ses Session that caused GridException.
+     * @param ses Session that caused IgniteCheckedException.
      * @param ex GridNioException instance.
@@ -98,43 +98,43 @@ public interface GridNioFilter {
      * @param ex GridNioException instance.
-     * @throws GridException If GridException occurred while handling event.
+     * @throws IgniteCheckedException If IgniteCheckedException occurred while handling event.
      */
@@ -144,93 +144,93 @@ public interface GridNioFilter {
      * @param ses Session on which message was received.
      * @param msg Received message.
-     * @throws GridException If GridException occurred while handling event.
+     * @throws IgniteCheckedException If IgniteCheckedException occurred while handling event.
      */
@@ -144,93 +144,93 @@ public interface GridNioFilter {
      * @param ses Session to close.
      * @return Close future.
-     * @throws GridException If GridException occurred while handling event.
+     * @throws IgniteCheckedException If IgniteCheckedException occurred while handling event.
      */
@@ -144,93 +144,93 @@ public interface GridNioFilter {
      *
      * @param ses Session that is idle.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -144,93 +144,93 @@ public interface GridNioFilter {
      *
      * @param ses Session instance.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -144,93 +144,93 @@ public interface GridNioFilter {
      *
      * @param ses Session that has timed out writes.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -144,93 +144,93 @@ public interface GridNioFilter {
      *
      * @param ses Session instance.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -144,93 +144,93 @@ public interface GridNioFilter {
      * @param ses Session.
      * @return Future for operation.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -144,93 +144,93 @@ public interface GridNioFilter {
      * @param ses Session.
      * @return Future for operation.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -144,93 +144,93 @@ public interface GridNioFilter {
      * @param ses Session.
      * @return Future for operation.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
@@ -144,93 +144,93 @@ public interface GridNioFilter {
      * @param ses Session.
      * @return Future for operation.
-     * @throws GridException If filter is not in chain or GridNioException occurred in the underlying filter.
+     * @throws IgniteCheckedException If filter is not in chain or GridNioException occurred in the underlying filter.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilterChain.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilterChain.java
index 70bf0bf..894c538 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilterChain.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFilterChain.java
@@ -123,9 +123,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      * Starts chain notification from head to tail.
      *
      * @param ses Session that was created.
      * @throws GridException If GridException occurred while handling event.
      */
-    @Override public void onSessionOpened(GridNioSession ses) throws GridException {
+    @Override public void onSessionOpened(GridNioSession ses) throws IgniteCheckedException {
         head.onSessionOpened(ses);
     }
 
@@ -133,9 +133,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      * Starts chain notification from head to tail.
      *
      * @param ses Session that was closed.
      * @throws GridException If GridException occurred while handling event.
      */
-    @Override public void onSessionClosed(GridNioSession ses) throws GridException {
+    @Override public void onSessionClosed(GridNioSession ses) throws IgniteCheckedException {
         head.onSessionClosed(ses);
     }
 
@@ -143,9 +143,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      * Starts chain notification from head to tail.
      *
      * @param ses Session in which GridNioException was caught.
-     * @param e GridException instance.
+     * @param e IgniteCheckedException instance.
      */
-    @Override public void onExceptionCaught(GridNioSession ses, GridException e) {
+    @Override public void onExceptionCaught(GridNioSession ses, IgniteCheckedException e) {
         try {
             head.onExceptionCaught(ses, e);
         }
@@ -159,9 +159,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      *
      * @param ses Session in which message was received.
      * @param msg Received message.
      * @throws GridException If GridException occurred while handling event.
      */
-    @Override public void onMessageReceived(GridNioSession ses, Object msg) throws GridException {
+    @Override public void onMessageReceived(GridNioSession ses, Object msg) throws IgniteCheckedException {
         head.onMessageReceived(ses, msg);
     }
 
@@ -171,9 +171,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      * @param ses Session to which message should be written.
      * @param msg Message to write.
      * @return Send future.
      * @throws GridException If GridException occurred while handling event.
      */
-    @Override public GridNioFuture<?> onSessionWrite(GridNioSession ses, Object msg) throws GridException {
+    @Override public GridNioFuture<?> onSessionWrite(GridNioSession ses, Object msg) throws IgniteCheckedException {
         return tail.onSessionWrite(ses, msg);
     }
 
@@ -182,19 +182,19 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      *
      * @param ses Session to close.
      * @return Close future.
      * @throws GridException If GridException occurred while handling event.
      */
-    @Override public GridNioFuture<Boolean> onSessionClose(GridNioSession ses) throws GridException {
+    @Override public GridNioFuture<Boolean> onSessionClose(GridNioSession ses) throws IgniteCheckedException {
         return tail.onSessionClose(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionIdleTimeout(GridNioSession ses) throws GridException {
+    @Override public void onSessionIdleTimeout(GridNioSession ses) throws IgniteCheckedException {
         head.onSessionIdleTimeout(ses);
     }
 
     /** {@inheritDoc} */
-    @Override public void onSessionWriteTimeout(GridNioSession ses) throws GridException {
+    @Override public void onSessionWriteTimeout(GridNioSession ses) throws IgniteCheckedException {
         head.onSessionWriteTimeout(ses);
     }
 
@@ -203,9 +203,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      *
      * @param ses Session to pause reads.
      * @return Future.
      * @throws GridException If GridException occurred while handling event.
      */
-    @Override public GridNioFuture<?> onPauseReads(GridNioSession ses) throws GridException {
+    @Override public GridNioFuture<?> onPauseReads(GridNioSession ses) throws IgniteCheckedException {
         return tail.onPauseReads(ses);
     }
 
@@ -214,9 +214,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      *
      * @param ses Session to resume reads.
      * @return Future.
      * @throws GridException If GridException occurred while handling event.
      */
-    @Override public GridNioFuture<?> onResumeReads(GridNioSession ses) throws GridException {
+    @Override public GridNioFuture<?> onResumeReads(GridNioSession ses) throws IgniteCheckedException {
         return tail.onResumeReads(ses);
     }
 
@@ -242,18 +242,18 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
         }
 
         /** {@inheritDoc} */
-        @Override public void onExceptionCaught(GridNioSession ses, GridException ex) {
+        @Override public void onExceptionCaught(GridNioSession ses, IgniteCheckedException ex) {
             lsnr.onDisconnected(ses, ex);
         }
 
         /** {@inheritDoc} */
         @Override public GridNioFuture<?> onSessionWrite(GridNioSession ses, Object msg)
-            throws GridException {
+            throws IgniteCheckedException {
             return proceedSessionWrite(ses, msg);
         }
 
         /** {@inheritDoc} */
-        @Override public GridNioFuture<Boolean> onSessionClose(GridNioSession ses) throws GridException {
+        @Override public GridNioFuture<Boolean> onSessionClose(GridNioSession ses) throws IgniteCheckedException {
             return proceedSessionClose(ses);
         }
 
@@ -263,22 +263,22 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
         }
 
         /** {@inheritDoc} */
-        @Override public void onSessionIdleTimeout(GridNioSession ses) throws GridException {
+        @Override public void onSessionIdleTimeout(GridNioSession ses) throws IgniteCheckedException {
             lsnr.onSessionIdleTimeout(ses);
         }
 
         /** {@inheritDoc} */
-        @Override public void onSessionWriteTimeout(GridNioSession ses) throws GridException {
+        @Override public void onSessionWriteTimeout(GridNioSession ses) throws IgniteCheckedException {
             lsnr.onSessionWriteTimeout(ses);
         }
 
         /** {@inheritDoc} */
-        @Override public GridNioFuture<?> onPauseReads(GridNioSession ses) throws GridException {
+        @Override public GridNioFuture<?> onPauseReads(GridNioSession ses) throws IgniteCheckedException {
             return proceedPauseReads(ses);
         }
 
         /** {@inheritDoc} */
-        @Override public GridNioFuture<?> onResumeReads(GridNioSession ses) throws GridException {
+        @Override public GridNioFuture<?> onResumeReads(GridNioSession ses) throws IgniteCheckedException {
             return proceedResumeReads(ses);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFinishedFuture.java
----------------------------------------------------------------------
@@ -123,9 +123,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      *
      * @param ses Session that was created.
-     * @throws GridException If GridException occurred while handling event.
+     * @throws IgniteCheckedException If IgniteCheckedException occurred while handling event.
      */
@@ -133,9 +133,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      *
      * @param ses Session that was closed.
-     * @throws GridException If GridException occurred while handling event.
+     * @throws IgniteCheckedException If IgniteCheckedException occurred while handling event.
      */
@@ -159,9 +159,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      * @param ses Session in which message was received.
      * @param msg Received message.
-     * @throws GridException If GridException occurred while handling event.
+     * @throws IgniteCheckedException If IgniteCheckedException occurred while handling event.
      */
@@ -171,9 +171,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      * @param msg Message to write.
      * @return Send future.
-     * @throws GridException If GridException occurred while handling event.
+     * @throws IgniteCheckedException If IgniteCheckedException occurred while handling event.
      */
@@ -182,19 +182,19 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      * @param ses Session to close.
      * @return Close future.
-     * @throws GridException If GridException occurred while handling event.
+     * @throws IgniteCheckedException If IgniteCheckedException occurred while handling event.
      */
@@ -203,9 +203,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      * @param ses Session to pause reads.
      * @return Future.
-     * @throws GridException If GridException occurred while handling event.
+     * @throws IgniteCheckedException If IgniteCheckedException occurred while handling event.
      */
@@ -214,9 +214,9 @@ public class GridNioFilterChain<T> extends GridNioFilterAdapter {
      * @param ses Session to resume reads.
      * @return Future.
-     * @throws GridException If GridException occurred while handling event.
+     * @throws IgniteCheckedException If IgniteCheckedException occurred while handling event.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java
index 2775c55..1754db7 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java
@@ -9,6 +9,7 @@
 
 package org.gridgain.grid.util.nio;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.gridgain.grid.*;
 import org.jetbrains.annotations.*;
@@ -27,12 +28,12 @@ public interface GridNioFuture<R> {
      * returns operation result.
      *
      * @return Operation result.
      * @throws GridInterruptedException Subclass of {@link GridException} thrown if the wait was interrupted.
      * @throws org.apache.ignite.lang.IgniteFutureCancelledException Subclass of {@link GridException} throws if operation was cancelled.
      * @throws GridException If operation failed.
      * @throws IOException If IOException occurred while performing operation.
      */
-    public R get() throws IOException, GridException;
+    public R get() throws IOException, IgniteCheckedException;
 
     /**
      * Synchronously waits for completion of the operation for
@@ -41,13 +42,13 @@ public interface GridNioFuture<R> {
      *
      * @param timeout The maximum time to wait in milliseconds.
      * @return Operation result.
      * @throws GridInterruptedException Subclass of {@link GridException} thrown if the wait was interrupted.
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException Subclass of {@link GridException} thrown if the wait was timed out.
      * @throws org.apache.ignite.lang.IgniteFutureCancelledException Subclass of {@link GridException} throws if operation was cancelled.
      * @throws GridException If operation failed.
      * @throws IOException If IOException occurred while performing operation.
      */
-    public R get(long timeout) throws IOException, GridException;
+    public R get(long timeout) throws IOException, IgniteCheckedException;
 
     /**
      * Synchronously waits for completion of the operation for
@@ -56,21 +57,21 @@ public interface GridNioFuture<R> {
      * @param timeout The maximum time to wait.
      * @param unit The time unit of the {@code timeout} argument.
      * @return Operation result.
      * @throws GridInterruptedException Subclass of {@link GridException} thrown if the wait was interrupted.
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException Subclass of {@link GridException} thrown if the wait was timed out.
      * @throws org.apache.ignite.lang.IgniteFutureCancelledException Subclass of {@link GridException} throws if operation was cancelled.
      * @throws GridException If operation failed.
      * @throws IOException If IOException occurred while performing operation.
      */
-    public R get(long timeout, TimeUnit unit) throws IOException, GridException;
+    public R get(long timeout, TimeUnit unit) throws IOException, IgniteCheckedException;
 
     /**
      * Cancels this future.
      *
      * @return {@code True} if future was canceled (i.e. was not finished prior to this call).
      * @throws GridException If cancellation failed.
      */
-    public boolean cancel() throws GridException;
+    public boolean cancel() throws IgniteCheckedException;
 
     /**
      * Checks if operation is done.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java
----------------------------------------------------------------------
@@ -27,12 +28,12 @@ public interface GridNioFuture<R> {
      *
      * @return Operation result.
-     * @throws GridInterruptedException Subclass of {@link GridException} thrown if the wait was interrupted.
-     * @throws org.apache.ignite.lang.IgniteFutureCancelledException Subclass of {@link GridException} throws if operation was cancelled.
-     * @throws GridException If operation failed.
+     * @throws GridInterruptedException Subclass of {@link IgniteCheckedException} thrown if the wait was interrupted.
+     * @throws org.apache.ignite.lang.IgniteFutureCancelledException Subclass of {@link IgniteCheckedException} throws if operation was cancelled.
+     * @throws IgniteCheckedException If operation failed.
      * @throws IOException If IOException occurred while performing operation.
      */
@@ -41,13 +42,13 @@ public interface GridNioFuture<R> {
      * @param timeout The maximum time to wait in milliseconds.
      * @return Operation result.
-     * @throws GridInterruptedException Subclass of {@link GridException} thrown if the wait was interrupted.
-     * @throws org.apache.ignite.lang.IgniteFutureTimeoutException Subclass of {@link GridException} thrown if the wait was timed out.
-     * @throws org.apache.ignite.lang.IgniteFutureCancelledException Subclass of {@link GridException} throws if operation was cancelled.
-     * @throws GridException If operation failed.
+     * @throws GridInterruptedException Subclass of {@link IgniteCheckedException} thrown if the wait was interrupted.
+     * @throws org.apache.ignite.lang.IgniteFutureTimeoutException Subclass of {@link IgniteCheckedException} thrown if the wait was timed out.
+     * @throws org.apache.ignite.lang.IgniteFutureCancelledException Subclass of {@link IgniteCheckedException} throws if operation was cancelled.
+     * @throws IgniteCheckedException If operation failed.
      * @throws IOException If IOException occurred while performing operation.
      */
@@ -56,21 +57,21 @@ public interface GridNioFuture<R> {
      * @param unit The time unit of the {@code timeout} argument.
      * @return Operation result.
-     * @throws GridInterruptedException Subclass of {@link GridException} thrown if the wait was interrupted.
-     * @throws org.apache.ignite.lang.IgniteFutureTimeoutException Subclass of {@link GridException} thrown if the wait was timed out.
-     * @throws org.apache.ignite.lang.IgniteFutureCancelledException Subclass of {@link GridException} throws if operation was cancelled.
-     * @throws GridException If operation failed.
+     * @throws GridInterruptedException Subclass of {@link IgniteCheckedException} thrown if the wait was interrupted.
+     * @throws org.apache.ignite.lang.IgniteFutureTimeoutException Subclass of {@link IgniteCheckedException} thrown if the wait was timed out.
+     * @throws org.apache.ignite.lang.IgniteFutureCancelledException Subclass of {@link IgniteCheckedException} throws if operation was cancelled.
+     * @throws IgniteCheckedException If operation failed.
      * @throws IOException If IOException occurred while performing operation.
      */
@@ -56,21 +57,21 @@ public interface GridNioFuture<R> {
      *
      * @return {@code True} if future was canceled (i.e. was not finished prior to this call).
-     * @throws GridException If cancellation failed.
+     * @throws IgniteCheckedException If cancellation failed.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java
index 3d5c4e9..6c5a6bc 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java
@@ -9,10 +9,11 @@
 
 package org.gridgain.grid.util.nio;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.gridgain.grid.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.tostring.*;
+import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -73,7 +74,7 @@ public class GridNioFutureImpl<R> extends AbstractQueuedSynchronizer implements
     }
 
     /** {@inheritDoc} */
-    @Override public R get() throws IOException, GridException {
+    @Override public R get() throws IOException, IgniteCheckedException {
         try {
             if (endTime == 0)
                 acquireSharedInterruptibly(0);
@@ -94,13 +95,13 @@ public class GridNioFutureImpl<R> extends AbstractQueuedSynchronizer implements
     }
 
     /** {@inheritDoc} */
-    @Override public R get(long timeout) throws IOException, GridException {
+    @Override public R get(long timeout) throws IOException, IgniteCheckedException {
         // Do not replace with static import, as it may not compile.
         return get(timeout, TimeUnit.MILLISECONDS);
     }
 
     /** {@inheritDoc} */
-    @Override public R get(long timeout, TimeUnit unit) throws IOException, GridException {
+    @Override public R get(long timeout, TimeUnit unit) throws IOException, IgniteCheckedException {
         A.ensure(timeout >= 0, "timeout cannot be negative: " + timeout);
         A.notNull(unit, "unit");
 
@@ -119,9 +120,9 @@ public class GridNioFutureImpl<R> extends AbstractQueuedSynchronizer implements
      * @return Result.
      * @throws InterruptedException If interrupted.
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException If timeout reached before computation completed.
      * @throws GridException If error occurred.
      */
-    @Nullable protected R get0(long nanosTimeout) throws InterruptedException, GridException {
+    @Nullable protected R get0(long nanosTimeout) throws InterruptedException, IgniteCheckedException {
         if (endTime == 0 && !tryAcquireSharedNanos(0, nanosTimeout))
             throw new IgniteFutureTimeoutException("Timeout was reached before computation completed.");
 
@@ -140,7 +141,7 @@ public class GridNioFutureImpl<R> extends AbstractQueuedSynchronizer implements
      * and call {@link #onCancelled()} callback explicitly if cancellation
      * indeed did happen.
      */
-    @Override public boolean cancel() throws GridException {
+    @Override public boolean cancel() throws IgniteCheckedException {
         return false;
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioParser.java
----------------------------------------------------------------------
@@ -119,9 +120,9 @@ public class GridNioFutureImpl<R> extends AbstractQueuedSynchronizer implements
      * @throws InterruptedException If interrupted.
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException If timeout reached before computation completed.
-     * @throws GridException If error occurred.
+     * @throws IgniteCheckedException If error occurred.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioParser.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioParser.java
index 68e67a7..969cc95 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioParser.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioParser.java
@@ -8,7 +8,7 @@
  */
 package org.gridgain.grid.util.nio;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -33,9 +33,9 @@ public interface GridNioParser {
      * @return Parsed user message or {@code null} if complete message has not been received yet. Note
      *         that in case of returning {@code null} given buffer must be completely read.
      * @throws IOException If exception occurred while reading data.
      * @throws GridException If any user-specific error occurred.
      */
-    @Nullable public Object decode(GridNioSession ses, ByteBuffer buf) throws IOException, GridException;
+    @Nullable public Object decode(GridNioSession ses, ByteBuffer buf) throws IOException, IgniteCheckedException;
 
     /**
      * This method is called whenever a message should be sent to the network connection
@@ -47,7 +47,7 @@ public interface GridNioParser {
      * @param msg Message to encode.
      * @return Buffer containing encoded message.
      * @throws IOException If exception occurred while encoding data.
      * @throws GridException If any user-specific error occurred while encoding data.
      */
-    public ByteBuffer encode(GridNioSession ses, Object msg) throws IOException, GridException;
+    public ByteBuffer encode(GridNioSession ses, Object msg) throws IOException, IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java
----------------------------------------------------------------------
@@ -33,9 +33,9 @@ public interface GridNioParser {
      *         that in case of returning {@code null} given buffer must be completely read.
      * @throws IOException If exception occurred while reading data.
-     * @throws GridException If any user-specific error occurred.
+     * @throws IgniteCheckedException If any user-specific error occurred.
      */
@@ -47,7 +47,7 @@ public interface GridNioParser {
      * @return Buffer containing encoded message.
      * @throws IOException If exception occurred while encoding data.
-     * @throws GridException If any user-specific error occurred while encoding data.
+     * @throws IgniteCheckedException If any user-specific error occurred while encoding data.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java
index 1e61a17..72ec526 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java
@@ -163,7 +163,7 @@ public class GridNioServer<T> {
      * @param metricsLsnr Metrics listener.
      * @param msgWriter Message writer.
      * @param filters Filters for this server.
      * @throws GridException If failed.
      */
     private GridNioServer(
         InetAddress addr,
@@ -183,7 +183,7 @@ public class GridNioServer<T> {
         GridNioMetricsListener metricsLsnr,
         GridNioMessageWriter msgWriter,
         GridNioFilter... filters
-    ) throws GridException {
+    ) throws IgniteCheckedException {
         A.notNull(addr, "addr");
         A.notNull(lsnr, "lsnr");
         A.notNull(log, "log");
@@ -460,9 +460,9 @@ public class GridNioServer<T> {
      *
      * @param addr Local address to listen on.
      * @return Created selector.
      * @throws GridException If selector could not be created or port is already in use.
      */
-    private Selector createSelector(@Nullable SocketAddress addr) throws GridException {
+    private Selector createSelector(@Nullable SocketAddress addr) throws IgniteCheckedException {
         Selector selector = null;
 
         ServerSocketChannel srvrCh = null;
@@ -494,7 +494,7 @@ public class GridNioServer<T> {
             U.close(srvrCh, log);
             U.close(selector, log);
 
-            throw new GridException("Failed to initialize NIO selector.", e);
+            throw new IgniteCheckedException("Failed to initialize NIO selector.", e);
         }
     }
 
@@ -527,10 +527,10 @@ public class GridNioServer<T> {
          * @param gridName Grid name.
          * @param name Worker name.
          * @param log Logger.
          * @throws GridException If selector could not be created.
          */
         protected ByteBufferNioClientWorker(int idx, @Nullable String gridName, String name, IgniteLogger log)
-            throws GridException {
+            throws IgniteCheckedException {
             super(idx, gridName, name, log);
 
             readBuf = directBuf ? ByteBuffer.allocateDirect(8 << 10) : ByteBuffer.allocate(8 << 10);
@@ -590,7 +590,7 @@ public class GridNioServer<T> {
                     readBuf.clear();
                 }
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 close(ses, e);
             }
         }
@@ -672,10 +672,10 @@ public class GridNioServer<T> {
          * @param gridName Grid name.
          * @param name Worker name.
          * @param log Logger.
          * @throws GridException If selector could not be created.
          */
         protected DirectNioClientWorker(int idx, @Nullable String gridName, String name, IgniteLogger log)
-            throws GridException {
+            throws IgniteCheckedException {
             super(idx, gridName, name, log);
         }
 
@@ -728,7 +728,7 @@ public class GridNioServer<T> {
                 else
                     readBuf.clear();
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 close(ses, e);
             }
         }
@@ -1035,10 +1035,10 @@ public class GridNioServer<T> {
          * @param gridName Grid name.
          * @param name Worker name.
          * @param log Logger.
          * @throws GridException If selector could not be created.
          */
         protected AbstractNioClientWorker(int idx, @Nullable String gridName, String name, IgniteLogger log)
-            throws GridException {
+            throws IgniteCheckedException {
             super(gridName, name, log);
 
             selector = createSelector(null);
@@ -1057,7 +1057,7 @@ public class GridNioServer<T> {
 
                         bodyInternal();
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         if (!Thread.currentThread().isInterrupted()) {
                             U.error(log, "Failed to read data from remote connection (will wait for " +
                                 ERR_WAIT_TIME + "ms).", e);
@@ -1088,10 +1088,10 @@ public class GridNioServer<T> {
         /**
          * Processes read and write events and registration requests.
          *
          * @throws GridException If IOException occurred or thread was unable to add worker to workers pool.
          */
         @SuppressWarnings("unchecked")
-        private void bodyInternal() throws GridException {
+        private void bodyInternal() throws IgniteCheckedException {
             try {
                 while (!closed && selector.isOpen()) {
                     NioOperationFuture req;
@@ -1179,10 +1179,10 @@ public class GridNioServer<T> {
                     log.debug("Closing selector due to thread interruption: " + e.getMessage());
             }
             catch (ClosedSelectorException e) {
-                throw new GridException("Selector got closed while active.", e);
+                throw new IgniteCheckedException("Selector got closed while active.", e);
             }
             catch (IOException e) {
-                throw new GridException("Failed to select events on selector.", e);
+                throw new IgniteCheckedException("Failed to select events on selector.", e);
             }
             finally {
                 if (selector.isOpen()) {
@@ -1279,7 +1279,7 @@ public class GridNioServer<T> {
                         ses.bytesReceived(0);
                     }
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     close(ses,  e);
                 }
             }
@@ -1335,7 +1335,7 @@ public class GridNioServer<T> {
 
                     req.onDone(ses);
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     close(ses, e);
 
                     req.onDone(e);
@@ -1357,7 +1357,7 @@ public class GridNioServer<T> {
          * @param e Exception to be passed to the listener, if any.
          * @return {@code True} if this call closed the ses.
          */
-        protected boolean close(final GridSelectorNioSessionImpl ses, @Nullable final GridException e) {
+        protected boolean close(final GridSelectorNioSessionImpl ses, @Nullable final IgniteCheckedException e) {
             if (e != null) {
                 // Print stack trace only if has runtime exception in it's cause.
                 if (e.hasCause(IOException.class))
@@ -1409,7 +1409,7 @@ public class GridNioServer<T> {
                 try {
                     filterChain.onSessionClosed(ses);
                 }
-                catch (GridException e1) {
+                catch (IgniteCheckedException e1) {
                     filterChain.onExceptionCaught(ses, e1);
                 }
 
@@ -1492,7 +1492,7 @@ public class GridNioServer<T> {
 
                         accept();
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         if (!Thread.currentThread().isInterrupted()) {
                             U.error(log, "Failed to accept remote connection (will wait for " + ERR_WAIT_TIME + "ms).",
                                 e);
@@ -1512,9 +1512,9 @@ public class GridNioServer<T> {
         /**
          * Accepts connections and schedules them for processing by one of read workers.
          *
          * @throws GridException If failed.
          */
-        private void accept() throws GridException {
+        private void accept() throws IgniteCheckedException {
             try {
                 while (!closed && selector.isOpen() && !Thread.currentThread().isInterrupted()) {
                     // Wake up every 2 seconds to check if closed.
@@ -1530,10 +1530,10 @@ public class GridNioServer<T> {
                         ", err=" + e.getMessage() + ']');
             }
             catch (ClosedSelectorException e) {
-                throw new GridException("Selector got closed while active: " + this, e);
+                throw new IgniteCheckedException("Selector got closed while active: " + this, e);
             }
             catch (IOException e) {
-                throw new GridException("Failed to accept connection: " + this, e);
+                throw new IgniteCheckedException("Failed to accept connection: " + this, e);
             }
             finally {
                 closeSelector();
@@ -1816,7 +1816,7 @@ public class GridNioServer<T> {
         }
 
         /** {@inheritDoc} */
-        @Override public void onSessionOpened(GridNioSession ses) throws GridException {
+        @Override public void onSessionOpened(GridNioSession ses) throws IgniteCheckedException {
             if (directMode && sslFilter != null)
                 ses.addMeta(BUF_SSL_SYSTEM_META_KEY, new ConcurrentLinkedDeque8<>());
 
@@ -1824,12 +1824,12 @@ public class GridNioServer<T> {
         }
 
         /** {@inheritDoc} */
-        @Override public void onSessionClosed(GridNioSession ses) throws GridException {
+        @Override public void onSessionClosed(GridNioSession ses) throws IgniteCheckedException {
             proceedSessionClosed(ses);
         }
 
         /** {@inheritDoc} */
-        @Override public void onExceptionCaught(GridNioSession ses, GridException ex) throws GridException {
+        @Override public void onExceptionCaught(GridNioSession ses, IgniteCheckedException ex) throws IgniteCheckedException {
             proceedExceptionCaught(ses, ex);
         }
 
@@ -1858,7 +1858,7 @@ public class GridNioServer<T> {
         }
 
         /** {@inheritDoc} */
-        @Override public void onMessageReceived(GridNioSession ses, Object msg) throws GridException {
+        @Override public void onMessageReceived(GridNioSession ses, Object msg) throws IgniteCheckedException {
             proceedMessageReceived(ses, msg);
         }
 
@@ -1868,22 +1868,22 @@ public class GridNioServer<T> {
         }
 
         /** {@inheritDoc} */
-        @Override public void onSessionIdleTimeout(GridNioSession ses) throws GridException {
+        @Override public void onSessionIdleTimeout(GridNioSession ses) throws IgniteCheckedException {
             proceedSessionIdleTimeout(ses);
         }
 
         /** {@inheritDoc} */
-        @Override public void onSessionWriteTimeout(GridNioSession ses) throws GridException {
+        @Override public void onSessionWriteTimeout(GridNioSession ses) throws IgniteCheckedException {
             proceedSessionWriteTimeout(ses);
         }
 
         /** {@inheritDoc} */
-        @Override public GridNioFuture<?> onPauseReads(GridNioSession ses) throws GridException {
+        @Override public GridNioFuture<?> onPauseReads(GridNioSession ses) throws IgniteCheckedException {
             return pauseResumeReads(ses, NioOperation.PAUSE_READ);
         }
 
         /** {@inheritDoc} */
-        @Override public GridNioFuture<?> onResumeReads(GridNioSession ses) throws GridException {
+        @Override public GridNioFuture<?> onResumeReads(GridNioSession ses) throws IgniteCheckedException {
             return pauseResumeReads(ses, NioOperation.RESUME_READ);
         }
     }
@@ -1957,9 +1957,9 @@ public class GridNioServer<T> {
          * Finishes building the instance.
          *
          * @return Final instance of {@link GridNioServer}.
          * @throws GridException If NIO client worker creation failed or address is already in use.
          */
-        public GridNioServer<T> build() throws GridException {
+        public GridNioServer<T> build() throws IgniteCheckedException {
             GridNioServer<T> ret = new GridNioServer<>(
                 addr,
                 port,

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServerBuffer.java
----------------------------------------------------------------------
@@ -163,7 +163,7 @@ public class GridNioServer<T> {
      * @param msgWriter Message writer.
      * @param filters Filters for this server.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     private GridNioServer(
@@ -460,9 +460,9 @@ public class GridNioServer<T> {
      * @param addr Local address to listen on.
      * @return Created selector.
-     * @throws GridException If selector could not be created or port is already in use.
+     * @throws IgniteCheckedException If selector could not be created or port is already in use.
      */
@@ -527,10 +527,10 @@ public class GridNioServer<T> {
          * @param name Worker name.
          * @param log Logger.
-         * @throws GridException If selector could not be created.
+         * @throws IgniteCheckedException If selector could not be created.
          */
         protected ByteBufferNioClientWorker(int idx, @Nullable String gridName, String name, IgniteLogger log)
@@ -672,10 +672,10 @@ public class GridNioServer<T> {
          * @param name Worker name.
          * @param log Logger.
-         * @throws GridException If selector could not be created.
+         * @throws IgniteCheckedException If selector could not be created.
          */
         protected DirectNioClientWorker(int idx, @Nullable String gridName, String name, IgniteLogger log)
@@ -1035,10 +1035,10 @@ public class GridNioServer<T> {
          * @param name Worker name.
          * @param log Logger.
-         * @throws GridException If selector could not be created.
+         * @throws IgniteCheckedException If selector could not be created.
          */
         protected AbstractNioClientWorker(int idx, @Nullable String gridName, String name, IgniteLogger log)
@@ -1088,10 +1088,10 @@ public class GridNioServer<T> {
          * Processes read and write events and registration requests.
          *
-         * @throws GridException If IOException occurred or thread was unable to add worker to workers pool.
+         * @throws IgniteCheckedException If IOException occurred or thread was unable to add worker to workers pool.
          */
         @SuppressWarnings("unchecked")
@@ -1512,9 +1512,9 @@ public class GridNioServer<T> {
          * Accepts connections and schedules them for processing by one of read workers.
          *
-         * @throws GridException If failed.
+         * @throws IgniteCheckedException If failed.
          */
@@ -1957,9 +1957,9 @@ public class GridNioServer<T> {
          *
          * @return Final instance of {@link GridNioServer}.
-         * @throws GridException If NIO client worker creation failed or address is already in use.
+         * @throws IgniteCheckedException If NIO client worker creation failed or address is already in use.
          */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServerBuffer.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServerBuffer.java
index a76a519..98fa73c 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServerBuffer.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServerBuffer.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.util.nio;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 import java.nio.*;
@@ -57,9 +57,9 @@ public class GridNioServerBuffer {
     /**
      * @param buf Buffer.
      * @return Message bytes or {@code null} if message is not fully read yet.
      * @throws GridException If failed to parse message.
      */
-    @Nullable public byte[] read(ByteBuffer buf) throws GridException {
+    @Nullable public byte[] read(ByteBuffer buf) throws IgniteCheckedException {
         if (cnt < 0) {
             for (; cnt < 0 && buf.hasRemaining(); cnt++) {
                 msgSize <<= 8;
@@ -72,7 +72,7 @@ public class GridNioServerBuffer {
 
             // If count is 0 then message size should be inited.
             if (msgSize <= 0)
-                throw new GridException("Invalid message size: " + msgSize);
+                throw new IgniteCheckedException("Invalid message size: " + msgSize);
 
             data = new byte[msgSize];
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioSessionImpl.java
----------------------------------------------------------------------
@@ -57,9 +57,9 @@ public class GridNioServerBuffer {
      * @param buf Buffer.
      * @return Message bytes or {@code null} if message is not fully read yet.
-     * @throws GridException If failed to parse message.
+     * @throws IgniteCheckedException If failed to parse message.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridShmemCommunicationClient.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridShmemCommunicationClient.java
index d5dec86..8777405 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridShmemCommunicationClient.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridShmemCommunicationClient.java
@@ -40,11 +40,11 @@ public class GridShmemCommunicationClient extends GridAbstractCommunicationClien
      * @param connTimeout Connection timeout.
      * @param log Logger.
      * @param msgWriter Message writer.
      * @throws GridException If failed.
      */
     public GridShmemCommunicationClient(GridNioMetricsListener metricsLsnr, int port, long connTimeout, IgniteLogger log,
         GridNioMessageWriter msgWriter)
-        throws GridException {
+        throws IgniteCheckedException {
         super(metricsLsnr);
 
         assert metricsLsnr != null;
@@ -63,7 +63,7 @@ public class GridShmemCommunicationClient extends GridAbstractCommunicationClien
 
     /** {@inheritDoc} */
     @Override public  synchronized void doHandshake(IgniteInClosure2X<InputStream, OutputStream> handshakeC)
-        throws GridException {
+        throws IgniteCheckedException {
         handshakeC.applyx(shmem.inputStream(), shmem.outputStream());
     }
 
@@ -86,9 +86,9 @@ public class GridShmemCommunicationClient extends GridAbstractCommunicationClien
     }
 
     /** {@inheritDoc} */
-    @Override public synchronized void sendMessage(byte[] data, int len) throws GridException {
+    @Override public synchronized void sendMessage(byte[] data, int len) throws IgniteCheckedException {
         if (closed())
-            throw new GridException("Communication client was closed: " + this);
+            throw new IgniteCheckedException("Communication client was closed: " + this);
 
         try {
             shmem.outputStream().write(data, 0, len);
@@ -96,7 +96,7 @@ public class GridShmemCommunicationClient extends GridAbstractCommunicationClien
             metricsLsnr.onBytesSent(len);
         }
         catch (IOException e) {
-            throw new GridException("Failed to send message to remote node: " + shmem, e);
+            throw new IgniteCheckedException("Failed to send message to remote node: " + shmem, e);
         }
 
         markUsed();
@@ -104,9 +104,9 @@ public class GridShmemCommunicationClient extends GridAbstractCommunicationClien
 
     /** {@inheritDoc} */
     @Override public synchronized void sendMessage(@Nullable UUID nodeId, GridTcpCommunicationMessageAdapter msg)
-        throws GridException {
+        throws IgniteCheckedException {
         if (closed())
-            throw new GridException("Communication client was closed: " + this);
+            throw new IgniteCheckedException("Communication client was closed: " + this);
 
         assert writeBuf.hasArray();
 
@@ -116,14 +116,14 @@ public class GridShmemCommunicationClient extends GridAbstractCommunicationClien
             metricsLsnr.onBytesSent(cnt);
         }
         catch (IOException e) {
-            throw new GridException("Failed to send message to remote node: " + shmem, e);
+            throw new IgniteCheckedException("Failed to send message to remote node: " + shmem, e);
         }
 
         markUsed();
     }
 
     /** {@inheritDoc} */
-    @Override public void sendMessage(ByteBuffer data) throws GridException {
+    @Override public void sendMessage(ByteBuffer data) throws IgniteCheckedException {
         throw new UnsupportedOperationException();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridTcpCommunicationClient.java
----------------------------------------------------------------------
@@ -40,11 +40,11 @@ public class GridShmemCommunicationClient extends GridAbstractCommunicationClien
      * @param log Logger.
      * @param msgWriter Message writer.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     public GridShmemCommunicationClient(GridNioMetricsListener metricsLsnr, int port, long connTimeout, IgniteLogger log,
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridTcpCommunicationClient.java b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridTcpCommunicationClient.java
index d1c8c5e..a20ea24 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridTcpCommunicationClient.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridTcpCommunicationClient.java
@@ -9,11 +9,11 @@
 
 package org.gridgain.grid.util.nio;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.direct.*;
-import org.jetbrains.annotations.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.lang.*;
+import org.gridgain.grid.util.typedef.internal.*;
+import org.jetbrains.annotations.*;
 
 import java.io.*;
 import java.net.*;
@@ -55,7 +55,7 @@ public class GridTcpCommunicationClient extends GridAbstractCommunicationClient
      * @param bufSize Buffer size (or {@code 0} to disable buffer).
      * @param minBufferedMsgCnt Minimum buffered message count.
      * @param bufSizeRatio Communication buffer size ratio.
      * @throws GridException If failed.
      */
     public GridTcpCommunicationClient(
         GridNioMetricsListener metricsLsnr,
@@ -69,7 +69,7 @@ public class GridTcpCommunicationClient extends GridAbstractCommunicationClient
         int bufSize,
         int minBufferedMsgCnt,
         double bufSizeRatio
-    ) throws GridException {
+    ) throws IgniteCheckedException {
         super(metricsLsnr);
 
         assert metricsLsnr != null;
@@ -114,7 +114,7 @@ public class GridTcpCommunicationClient extends GridAbstractCommunicationClient
             success = true;
         }
         catch (IOException e) {
-            throw new GridException("Failed to connect to remote host " +
+            throw new IgniteCheckedException("Failed to connect to remote host " +
                 "[addr=" + addr + ", localHost=" + locHost + ']', e);
         }
         finally {
@@ -124,12 +124,12 @@ public class GridTcpCommunicationClient extends GridAbstractCommunicationClient
     }
 
     /** {@inheritDoc} */
-    @Override public void doHandshake(IgniteInClosure2X<InputStream, OutputStream> handshakeC) throws GridException {
+    @Override public void doHandshake(IgniteInClosure2X<InputStream, OutputStream> handshakeC) throws IgniteCheckedException {
         try {
             handshakeC.applyx(sock.getInputStream(), sock.getOutputStream());
         }
         catch (IOException e) {
-            throw new GridException("Failed to access IO streams when executing handshake with remote node: " +
+            throw new IgniteCheckedException("Failed to access IO streams when executing handshake with remote node: " +
                 sock.getRemoteSocketAddress(), e);
         }
     }
@@ -165,9 +165,9 @@ public class GridTcpCommunicationClient extends GridAbstractCommunicationClient
     }
 
     /** {@inheritDoc} */
-    @Override public void sendMessage(byte[] data, int len) throws GridException {
+    @Override public void sendMessage(byte[] data, int len) throws IgniteCheckedException {
         if (closed())
-            throw new GridException("Client was closed: " + this);
+            throw new IgniteCheckedException("Client was closed: " + this);
 
         try {
             out.write(data, 0, len);
@@ -175,7 +175,7 @@ public class GridTcpCommunicationClient extends GridAbstractCommunicationClient
             metricsLsnr.onBytesSent(len);
         }
         catch (IOException e) {
-            throw new GridException("Failed to send message to remote node: " + sock.getRemoteSocketAddress(), e);
+            throw new IgniteCheckedException("Failed to send message to remote node: " + sock.getRemoteSocketAddress(), e);
         }
 
         markUsed();
@@ -183,9 +183,9 @@ public class GridTcpCommunicationClient extends GridAbstractCommunicationClient
 
     /** {@inheritDoc} */
     @Override public void sendMessage(@Nullable UUID nodeId, GridTcpCommunicationMessageAdapter msg)
-        throws GridException {
+        throws IgniteCheckedException {
         if (closed())
-            throw new GridException("Client was closed: " + this);
+            throw new IgniteCheckedException("Client was closed: " + this);
 
         assert writeBuf.hasArray();
 
@@ -195,7 +195,7 @@ public class GridTcpCommunicationClient extends GridAbstractCommunicationClient
             metricsLsnr.onBytesSent(cnt);
         }
         catch (IOException e) {
-            throw new GridException("Failed to send message to remote node: " + sock.getRemoteSocketAddress(), e);
+            throw new IgniteCheckedException("Failed to send message to remote node: " + sock.getRemoteSocketAddress(), e);
         }
 
         markUsed();
@@ -212,7 +212,7 @@ public class GridTcpCommunicationClient extends GridAbstractCommunicationClient
     }
 
     /** {@inheritDoc} */
-    @Override public void sendMessage(ByteBuffer data) throws GridException {
+    @Override public void sendMessage(ByteBuffer data) throws IgniteCheckedException {
         throw new UnsupportedOperationException();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridTcpNioCommunicationClient.java
----------------------------------------------------------------------
@@ -55,7 +55,7 @@ public class GridTcpCommunicationClient extends GridAbstractCommunicationClient
      * @param minBufferedMsgCnt Minimum buffered message count.
      * @param bufSizeRatio Communication buffer size ratio.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     public GridTcpCommunicationClient(